:py:mod:`icclim._core.legacy.user_index.model`
==============================================

.. py:module:: icclim._core.legacy.user_index.model

.. autoapi-nested-parse::

   Contain the UserIndexDict TypedDict.



Module Contents
---------------

.. py:class:: UserIndexDict




   User index dictionary.

   This dictionary is used to describe how a user index should be setup to compute a
   custom climate index.
   The reccomended way to create a custom indices is now to use the
   generic indices API.
   See :ref:`generic_indices_recipes` for how to combine thresholds with generic
